broadcast

package
v0.0.0-...-95272ce Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 11, 2017 License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Handler

type Handler interface {
	// Handle starts a service thread for a given gRPC connection and services the broadcast connection
	Handle(srv ab.AtomicBroadcast_BroadcastServer) error
}

Handler defines an interface which handles broadcasts

func NewHandlerImpl

func NewHandlerImpl(sm SupportManager, queueSize int) Handler

NewHandlerImpl constructs a new implementation of the Handler interface

type Support

type Support interface {
	// Enqueue accepts a message and returns true on acceptance, or false on shutdown
	Enqueue(env *cb.Envelope) bool

	// Filters returns the set of broadcast filters for this chain
	Filters() *filter.RuleSet
}

Support provides the backing resources needed to support broadcast on a chain

type SupportManager

type SupportManager interface {
	GetChain(chainID string) (Support, bool)
}

SupportManager provides a way for the Handler to look up the Support for a chain

Jump to